@@ -6,7 +6,7 @@ import json
 import re
 from datetime import datetime
 
-import pyTools as pyTools
+import rsi_python_lib.pyTools as pyTools
 
 # definizione dei namespaces per parsaqre gli atom
 namespaces = { 'atom':'{http://www.w3.org/2005/Atom}',
